<?php

namespace IQBall\App\Controller;

use IQBall\App\Session\SessionHandle;
use IQBall\App\Validator\TacticValidator;
use IQBall\App\ViewHttpResponse;
use IQBall\Core\Data\TacticInfo;
use IQBall\Core\Http\HttpCodes;
use IQBall\Core\Model\TacticModel;

class EditorController {
    private TacticModel $model;

    public function __construct(TacticModel $model) {
        $this->model = $model;
    }

    /**
     * @param TacticInfo $tactic
     * @return ViewHttpResponse the editor view for given tactic
     */
    private function openEditorFor(TacticInfo $tactic): ViewHttpResponse {
        return ViewHttpResponse::react("views/Editor.tsx", [
            "id" => $tactic->getId(),
            "name" => $tactic->getName(),
            "content" => $tactic->getContent(),
        ]);
    }

    /**
     * creates a new empty tactic, with default name
     * @param SessionHandle $session
     * @return ViewHttpResponse the editor view
     */
    public function createNew(SessionHandle $session): ViewHttpResponse {
        $tactic = $this->model->makeNewDefault($session->getAccount()->getId());
        return $this->openEditorFor($tactic);
    }

    /**
     * returns an editor view for a given tactic
     * @param int $id the targeted tactic identifier
     * @param SessionHandle $session
     * @return ViewHttpResponse
     */
    public function openEditor(int $id, SessionHandle $session): ViewHttpResponse {
        $tactic = $this->model->get($id);

        $failure = TacticValidator::validateAccess($id, $tactic, $session->getAccount()->getId());

        if ($failure != null) {
            return ViewHttpResponse::twig('error.html.twig', ['failures' => [$failure]], HttpCodes::NOT_FOUND);
        }

        return $this->openEditorFor($tactic);
    }


}
